@@ -1,4 +1,12 @@
 "[.createTable"<-function(x,i,...){
+  if (is.character(i)){
+    oo<-attr(attr(x,"x")[[1]],"varnames.orig")
+    oo<-structure(1:length(oo),names=oo)
+    if (!all(i%in%names(oo)))
+      warning("some specified variables in subsetting don't exist.\nBe sure to specify the name of selected variables by the 'original name' and not their label")
+    i<-oo[i]
+    i<-i[!is.na(i)]
+  } 
   class.orig<-class(x)
   if (inherits(x,"rbind.createTable"))
     stop("x cannot be of class rbind.createTable")
@@ -14,12 +22,4 @@
   ans<-eval(parse(text=paste("update(x,x=obj.i,hide=",hide,",digits=",digits,")",sep="")))
   class(ans)<-class.orig
   ans
-}
-
-
-
-
-
-
-
-
+}
\ No newline at end of file
